/*	+-----------------------------------------------------------------------------+
		| QuickDialog  2006 Campanile Data Systems - All Rights Reserved             |
		+-----------------------------------------------------------------------------+
		| A class for the Aurora compiler.                                           |
		+-----------------------------------------------------------------------------+
		| Usage:                                                                      |
		|                                                                             |
		| The purpose of this class is to make a quick, standardized dialog box.      |
		| The dialog has an image, caption for the image, a few lines of text, and    |
		| window title, and a link to your web site.                                  |
		|                                                                             |
		| To use, load your image as a resource, instantiate the class, and set the   |
		| variables.                                                                  |
		|                                                                             |
		| QuickDialog dlgAbout;                                                       |
		| ...                                                                         |
		| dlgAbout.SetTitle("About");                                                 |
		| dlgAbout.SetImage("logo"); // logo is an image resource                     |
		| dlgAbout.SetCaption("This is our pretty logo");                             |
		| dlgAbout.SetText("My program\n(c)My company");                              |
		| dlgAbout.SetLink("http://mycompany.com");                                   |
		| dlgAbout.Make(ptrParent); // this actually creates the dialog               |
		|                                                                             |
		| Then call it when ready:                                                    |
		|                                                                             |
		| dlgAbout.DoModal();                                                         |
		+-----------------------------------------------------------------------------+		
*/

#IFNDEF QUICKDIALOG
#DEFINE QUICKDIALOG

#IFNDEF STATICLINK
#INCLUDE "StaticLink.inc"
#ENDIF

class QuickDialog:CDialog
{
	// Constructor/Destructor
	declare  QuickDialog();
	declare _QuickDialog();
	// Overridden methods
	declare OnClose(), int;
	declare OnControl(int nID, int nNotifyCode, unsigned int hControl), int;
	declare OnInitDialog(),int;
	// Class methods
	declare Make(cwindow *parent), void;			 			// creates the dialog
	declare SetTitle(string sTitle), void;					// dialog title
	declare SetCaption(string sCaption), void;			// text under the image
	declare SetImage(string sID), void;							// the image
	declare SetLink(string sLink), void;						// http link under main text
	declare SetText(string sText), void;						// dialog main text
	// Class variables
	string m_sTitle;
	string m_sCaption;
	string m_sLink;
	string m_sText;
	int    m_TextHeight; // for main dialog text
	unsigned int m_hImage;
	StaticLink *pStatic;
	// Class constants
	const QD_OK      = 1; // for OnControl() method "quick dialog OK"
	const QD_IMAGE   = 2;
	const QD_CAPTION = 3;
	const QD_TEXT    = 4;
	const QD_LINK    = 5;
}

QuickDialog::QuickDialog()
{
	// initialize string variables
	m_sCaption = "";
	m_sLink    = "";
	m_sText    = "";
	m_sTitle   = "";
	return;
}

QuickDialog::_QuickDialog()
{
	return;
}

QuickDialog::Make(CWindow *parent), void
{
	Create(0,0,500,310,
		AWS_POPUP|AWS_BORDER|AWS_DLGFRAME|AWS_SYSMENU|DS_MODALFRAME,
		0,m_sTitle,parent);

	AddControl(CTBUTTON,"OK",215,260,70,20,
		ABS_OWNERDRAW|AWS_CHILD|AWS_VISIBLE|AWS_TABSTOP,0x0,
		QD_OK);

	AddControl(CTSTATIC,"",25,36,272,178,
		ASS_BITMAP|AWS_CHILD|AWS_VISIBLE|SS_NOTIFY|SS_CENTERIMAGE|SS_SUNKEN,0x0,
		QD_IMAGE);

	AddControl(CTSTATIC,"",25,214,272,40,
		AWS_CHILD|AWS_VISIBLE|SS_NOTIFY|ASS_MULTILINE,0x0,
		QD_CAPTION);

	AddControl(CTSTATIC,"",310,36,178,70,
		AWS_CHILD|AWS_VISIBLE|ASS_MULTILINE|SS_NOTIFY,0x0,
		QD_TEXT);

	if(m_sLink <> "")
	{
		AddControl(CTSTATIC,m_sLink,310,110,178,20,
			AWS_CHILD|AWS_VISIBLE|ASS_MULTILINE|SS_NOTIFY,
			0x0,QD_LINK);
	}

	return;
}

QuickDialog::OnControl(int nID, int nNotifyCode, unsigned int hControl), int
{
	select nID
	{
		case QD_OK:
		if(nNotifyCode = BN_CLICKED)
		{
			CloseDialog(IDOK);
			return true;
		}
	}
	return true;
}
QuickDialog::OnClose(), int
{
	delete pStatic;
	CloseDialog(IDCANCEL);
	return true;
}



QuickDialog::OnInitDialog(),int
{
	CStatic *pControl;

	pControl = GetControl(QD_IMAGE);
	pControl ->SetImage(m_hImage);

	pControl = GetControl(QD_CAPTION);
	pControl ->SetText(m_sCaption);

	pControl = GetControl(QD_TEXT);
	pControl ->SetText(m_sText);

	if(m_sLink <> "")
	{
	// create the static link and attach it to our static control
	pControl = GetControl(QD_LINK);
	pStatic= new(StaticLink,1);
	pStatic->m_hWnd = pControl->m_hWnd;
	SetPropA(pStatic->m_hWnd,"THIS",pStatic+0);
	pStatic->SetStaticText(m_sLink);
	pStatic ->SetColor(BLUE,GetSysColor(15)); 
	SetFont("",8,"500",SFUNDERLINE,QD_LINK);
	}
	CenterWindow();
	return true;
}

QuickDialog::SetTitle(string sTitle), void
{
	m_sTitle = sTitle;
	return;
}

QuickDialog::SetCaption(string sCaption), void
{
	// this is the caption under the image, not the caption for the window itself
	// one or two brief lines of text with "\n"
	m_sCaption = sCaption;
	return;
}

QuickDialog::SetImage(string sID), void
{
	// sID is the ID from the resource view
	m_hImage = LoadImageA(GetModuleHandleA(0),sID,0,0,0,0);
	if (m_hImage = null)
		MessageBox(this,"Image failed to load","",0);
	return;
}

QuickDialog::SetLink(string sLink), void
{
	// sLink is in the format www.blahblah.com
	m_sLink = sLink;
	return;
}

QuickDialog::SetText(string sText), void
{
	// lines separated by "\n"
	m_sText = sText;
	return;
}

#ENDIF
